@@ -1,5 +1,5 @@
 ;; jde-run.el --- runs the Java app in the current buffer.
-;; $Revision: 1.1 $ $Date: 2000/08/13 13:44:01 $
+;; $Revision: 1.2 $ $Date: 2000/10/06 08:51:20 $
 
 ;; Author: Paul Kinnucan <paulk@mathworks.com>
 ;; Maintainer: Paul Kinnucan
@@ -197,7 +197,7 @@ Property Value field. You can specify as many properties as you like."
   :group 'jde-run-options
   :type '(cons boolean
 	       (list
-		(string :tag "Ouput File Path")
+		(string :tag "Output File Path")
 		(integer :tag "Stack Trace Depth")
 		(integer :tag "Allocation Sites")
 		(radio-button-choice :format "%t \n%v"
@@ -858,6 +858,9 @@ file."
 
 ;; Change History
 ;; $Log: jde-run.el,v $
+;; Revision 1.2  2000/10/06 08:51:20  youngs
+;; Martin's Monster Mega typo patch
+;;
 ;; Revision 1.1  2000/08/13 13:44:01  michaels
 ;; Initial checkin.
 ;;
@@ -1030,4 +1033,4 @@ file."
 ;; Initial revision
 ;;
 
-;;; jde-run.el ends here
\ No newline at end of file
+;;; jde-run.el ends here
